@@ -13,7 +13,7 @@ use Test::Builder;
 use File::Find;
 use Scalar::Util qw(blessed);
 
-our $VERSION = '1.41_02';
+our $VERSION = '1.41_03';
 our $VERBOSE = 1;
 our $HOME;
 our $test_bool = 1;
@@ -167,7 +167,9 @@ sub ok_manifest {
         no_chdir => 1,
         follow   => 0,
         wanted   => sub {
-            my $file         = $File::Find::name;
+            my $file = $File::Find::name;
+            return if !-f $file;
+
             my $is_excluded  = _is_excluded(
                 $file,
                 $excluded,
@@ -177,9 +179,11 @@ sub ok_manifest {
                 $home,
             );
             
-            push @dir_files, File::Spec->rel2abs($file) if -f $file and !$is_excluded;
-            
-            $excluded{$file} = 1 if -f $file and $is_excluded
+            my $abs = File::Spec->rel2abs($file);
+
+            $is_excluded ?
+                ( $excluded{$abs} = 1 ) :
+                ( push @dir_files, $abs );
         }
     },$home);
 
@@ -386,7 +390,7 @@ Test::CheckManifest - Check if your Manifest matches your distro
 
 =head1 VERSION
 
-version 1.41_02
+version 1.41_03
 
 =head1 SYNOPSIS
 
